@@ -2,6 +2,6 @@
 #define K3BDEVICE_I18N_H
 
 #define TRANSLATION_DOMAIN "libk3bdevice"
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #endif // K3BDEVICE_I18N_H
